<?php
/**
 * @var $this yii\web\View
 */
use backend\assets\BackendAsset;
use backend\widgets\Menu;
use common\models\TimelineEvent;
use yii\helpers\ArrayHelper;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\widgets\Breadcrumbs;

$bundle = BackendAsset::register($this);
?>
<?php $this->beginContent('@backend/views/layouts/base.php'); ?>
    <div class="wrapper">
        <!-- header logo: style can be found in header.less -->
        <header class="main-header">
            <a href="<?= Yii::getAlias('@frontendUrl') ?>" class="logo">
                <!-- Add the class icon to your logo image or logo icon to add the margining -->
                <?= Yii::$app->name ?>
            </a>
            <!-- Header Navbar: style can be found in header.less -->
            <nav class="navbar navbar-static-top" role="navigation">
                <!-- Sidebar toggle button-->
                <a href="#" class="sidebar-toggle" data-toggle="offcanvas" role="button">
                    <span class="sr-only"><?= Yii::t('backend', 'Toggle navigation') ?></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </a>
                <div class="navbar-custom-menu">
                    <ul class="nav navbar-nav">
                        <li id="timeline-notifications" class="notifications-menu">
                            <a href="<?= Url::to(['/timeline-event/index']) ?>">
                                <i class="fa fa-bell"></i>
                                <span class="label label-success">
                                    <?= TimelineEvent::find()->today()->count() ?>
                                </span>
                            </a>
                        </li>
                        <!-- Notifications: style can be found in dropdown.less -->
                        <li id="log-dropdown" class="dropdown notifications-menu">
                            <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                                <i class="fa fa-warning"></i>
                                <span class="label label-danger">
                                <?= \backend\models\SystemLog::find()->count() ?>
                            </span>
                            </a>
                            <ul class="dropdown-menu">
                                <li class="header"><?= Yii::t('backend', 'You have {num} log items',
                                        ['num' => \backend\models\SystemLog::find()->count()]) ?></li>
                                <li>
                                    <!-- inner menu: contains the actual data -->
                                    <ul class="menu">
                                        <?php foreach (\backend\models\SystemLog::find()->orderBy(['log_time' => SORT_DESC])->limit(5)->all() as $logEntry): ?>
                                            <li>
                                                <a href="<?= Yii::$app->urlManager->createUrl([
                                                    '/log/view',
                                                    'id' => $logEntry->id
                                                ]) ?>">
                                                    <i class="fa fa-warning <?= $logEntry->level == \yii\log\Logger::LEVEL_ERROR ? 'text-red' : 'text-yellow' ?>"></i>
                                                    <?= $logEntry->category ?>
                                                </a>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                </li>
                                <li class="footer">
                                    <?= Html::a(Yii::t('backend', 'View all'), ['/log/index']) ?>
                                </li>
                            </ul>
                        </li>
                        <!-- User Account: style can be found in dropdown.less -->
                        <li class="dropdown user user-menu">
                            <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                                <img
                                    src="<?= Yii::$app->user->identity->userProfile->getAvatar($this->assetManager->getAssetUrl($bundle,
                                        'img/anonymous.jpg')) ?>"
                                    class="user-image">
                                <span><?= Yii::$app->user->identity->username ?> <i class="caret"></i></span>
                            </a>
                            <ul class="dropdown-menu">
                                <!-- User image -->
                                <li class="user-header light-blue">
                                    <img
                                        src="<?= Yii::$app->user->identity->userProfile->getAvatar($this->assetManager->getAssetUrl($bundle,
                                            'img/anonymous.jpg')) ?>"
                                        class="img-circle" alt="User Image"/>
                                    <p>
                                        <?= Yii::$app->user->identity->username ?>
                                        <small>
                                            <?= Yii::t('backend', 'Member since {0, date, short}',
                                                Yii::$app->user->identity->created_at) ?>
                                        </small>
                                </li>
                                <!-- Menu Footer-->
                                <li class="user-footer">
                                    <div class="pull-left">
                                        <?= Html::a(Yii::t('backend', 'Profile'), ['/sign-in/profile'],
                                            ['class' => 'btn btn-default btn-flat']) ?>
                                    </div>
                                    <div class="pull-left">
                                        <?= Html::a(Yii::t('backend', 'Account'), ['/sign-in/account'],
                                            ['class' => 'btn btn-default btn-flat']) ?>
                                    </div>
                                    <div class="pull-right">
                                        <?= Html::a(Yii::t('backend', 'Logout'), ['/sign-in/logout'],
                                            ['class' => 'btn btn-default btn-flat', 'data-method' => 'post']) ?>
                                    </div>
                                </li>
                            </ul>
                        </li>
                        <li>
                            <?= Html::a('<i class="fa fa-cogs"></i>', ['/site/settings']) ?>
                        </li>
                    </ul>
                </div>
            </nav>
        </header>
        <!-- Left side column. contains the logo and sidebar -->
        <aside class="main-sidebar">
            <!-- sidebar: style can be found in sidebar.less -->
            <section class="sidebar">
                <!-- Sidebar user panel -->
                <div class="user-panel">
                    <div class="pull-left image">
                        <img
                            src="<?= Yii::$app->user->identity->userProfile->getAvatar($this->assetManager->getAssetUrl($bundle,
                                'img/anonymous.jpg')) ?>"
                            class="img-circle"/>
                    </div>
                    <div class="pull-left info">
                        <p><?= Yii::t('backend', 'Hello, {username}',
                                ['username' => Yii::$app->user->identity->getPublicIdentity()]) ?></p>
                        <a href="<?= Url::to(['/sign-in/profile']) ?>">
                            <i class="fa fa-circle text-success"></i>
                            <?= Yii::$app->formatter->asDatetime(time()) ?>
                        </a>
                    </div>
                </div>
                <!-- sidebar menu: : style can be found in sidebar.less -->
                <?= Menu::widget([
                    'options' => ['class' => 'sidebar-menu'],
                    'linkTemplate' => '<a href="{url}">{icon}<span>{label}</span>{right-icon}{badge}</a>',
                    'submenuTemplate' => "\n<ul class=\"treeview-menu\">\n{items}\n</ul>\n",
                    'activateParents' => true,
                    'items' => [
                        [
                            'label' => Yii::t('backend', 'Main'),
                            'options' => ['class' => 'header']
                        ],
                        [
                            'label' => Yii::t('backend', 'Timeline'),
                            'icon' => '<i class="fa fa-bar-chart-o"></i>',
                            'url' => ['/timeline-event/index'],
                            'badge' => TimelineEvent::find()->today()->count(),
                            'badgeBgClass' => 'label-success',
                        ],
                        [
                            'label' => Yii::t('backend', 'Content'),
                            'url' => '#',
                            'icon' => '<i class="fa fa-edit"></i>',
                            'options' => ['class' => 'treeview'],
                            'items' => [
                                [
                                    'label' => Yii::t('backend', 'Static pages'),
                                    'url' => ['/page/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Articles'),
                                    'url' => ['/article/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Article Categories'),
                                    'url' => ['/article-category/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Text Widgets'),
                                    'url' => ['/widget-text/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Menu Widgets'),
                                    'url' => ['/widget-menu/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Carousel Widgets'),
                                    'url' => ['/widget-carousel/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                            ]
                        ],
                        [
                            'label' => Yii::t('backend', 'Category'),
                            'icon' => '<i class="fa fa-sitemap"></i>',
                            'url' => ['/theme/category/index'],
                            'visible' => Yii::$app->user->can('administrator')
                        ],
                        [
                            'label' => Yii::t('backend', 'Theme'),
                            'icon' => '<i class="fa fa-sitemap"></i>',
                            'url' => ['/theme/theme/index'],
                            'visible' => Yii::$app->user->can('administrator')
                        ],
                        [
                            'label' => Yii::t('backend', 'Website'),
                            'icon' => '<i class="fa fa-globe"></i>',
                            'url' => ['/website'],
                            'visible' => Yii::$app->user->can('administrator')
                        ],
                        [
                            'label' => Yii::t('backend', 'Location'),
                            'icon' => '<i class="fa fa-map"></i>',
                            'url' => '#',
                            'visible' => Yii::$app->user->can('administrator'),
                            'options' => ['class' => 'treeview'],
                            'items' => [
                                [
                                    'label' => Yii::t('backend', 'State'),
                                    'url' => ['/location/state'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'District'),
                                    'url' => ['/location/district'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                            ]
                        ],
                        [
                            'label' => Yii::t('backend', 'Business'),
                            'icon' => '<i class="fa fa-suitcase"></i>',
                            'url' => ['/business/business'],
                            'visible' => Yii::$app->user->can('administrator')
                        ],
                        [
                            'label' => Yii::t('backend', 'System'),
                            'options' => ['class' => 'header']
                        ],
                        [
                            'label' => Yii::t('backend', 'Users'),
                            'icon' => '<i class="fa fa-users"></i>',
                            'url' => ['/user/index'],
                            'visible' => Yii::$app->user->can('administrator')
                        ],
                        [
                            'label' => Yii::t('backend', 'Other'),
                            'url' => '#',
                            'icon' => '<i class="fa fa-cogs"></i>',
                            'options' => ['class' => 'treeview'],
                            'items' => [
                                [
                                    'label' => Yii::t('backend', 'i18n'),
                                    'url' => '#',
                                    'icon' => '<i class="fa fa-flag"></i>',
                                    'options' => ['class' => 'treeview'],
                                    'items' => [
                                        [
                                            'label' => Yii::t('backend', 'i18n Source Message'),
                                            'url' => ['/i18n/i18n-source-message/index'],
                                            'icon' => '<i class="fa fa-angle-double-right"></i>'
                                        ],
                                        [
                                            'label' => Yii::t('backend', 'i18n Message'),
                                            'url' => ['/i18n/i18n-message/index'],
                                            'icon' => '<i class="fa fa-angle-double-right"></i>'
                                        ],
                                    ]
                                ],
                                [
                                    'label' => Yii::t('backend', 'Key-Value Storage'),
                                    'url' => ['/key-storage/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'File Storage'),
                                    'url' => ['/file-storage/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Cache'),
                                    'url' => ['/cache/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'File Manager'),
                                    'url' => ['/file-manager/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'System Information'),
                                    'url' => ['/system-information/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>'
                                ],
                                [
                                    'label' => Yii::t('backend', 'Logs'),
                                    'url' => ['/log/index'],
                                    'icon' => '<i class="fa fa-angle-double-right"></i>',
                                    'badge' => \backend\models\SystemLog::find()->count(),
                                    'badgeBgClass' => 'label-danger',
                                ],
                            ]
                        ]
                    ]
                ]) ?>
            </section>
            <!-- /.sidebar -->
        </aside>

        <!-- Right side column. Contains the navbar and content of the page -->
        <aside class="content-wrapper">
            <!-- Content Header (Page header) -->
            <section class="content-header">
                <h1>
                    <?= $this->title ?>
                    <?php if (isset($this->params['subtitle'])): ?>
                        <small><?= $this->params['subtitle'] ?></small>
                    <?php endif; ?>
                </h1>

                <?= Breadcrumbs::widget([
                    'tag' => 'ol',
                    'links' => isset($this->params['breadcrumbs']) ? $this->params['breadcrumbs'] : [],
                ]) ?>
            </section>

            <!-- Main content -->
            <section class="content">
                <?php if (Yii::$app->session->hasFlash('alert')): ?>
                    <?= \yii\bootstrap\Alert::widget([
                        'body' => ArrayHelper::getValue(Yii::$app->session->getFlash('alert'), 'body'),
                        'options' => ArrayHelper::getValue(Yii::$app->session->getFlash('alert'), 'options'),
                    ]) ?>
                <?php endif; ?>
                <?= $content ?>
            </section><!-- /.content -->
        </aside><!-- /.right-side -->
    </div><!-- ./wrapper -->

<?php $this->endContent(); ?>