<?php

namespace common\models;

use Yii;
use yii\behaviors\SluggableBehavior;
use yii\behaviors\TimestampBehavior;

/**
 * This is the model class for table "{{%business}}".
 *
 * @property integer $id
 * @property integer $category_id
 * @property integer $district_id
 * @property string $domain_name
 * @property string $name
 * @property string $slug
 * @property string $address
 * @property string $landmark
 * @property string $mobile_no
 * @property string $toll_free_no
 * @property string $contact_no
 * @property string $fax
 * @property string $email
 * @property string $description
 * @property string $logo_base_url
 * @property string $logo_path
 * @property string $latitude
 * @property string $longitude
 * @property integer $status
 * @property integer $created_at
 * @property integer $updated_at
 *
 * @property Category $category
 * @property District $district
 */
class Business extends \yii\db\ActiveRecord
{
    const STATUS_ACTIVE = 1;
    const STATUS_IN_ACTIVE = 0;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%business}}';
    }

    /**
     * @inheritdoc
     */

    public function behaviors()
    {
        return [
            [
                'class' => SluggableBehavior::className(),
                'attribute' => 'name',
                'immutable' => true
            ],
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at'
            ]
        ];
    }

    public function rules()
    {
        return [
            [['category_id', 'district_id', 'status', 'created_at', 'updated_at'], 'integer'],
            [['domain_name', 'name', 'address', 'mobile_no', 'email'], 'required'],
            [['description'], 'string'],
            [['domain_name'], 'string', 'max' => 255],
            [['name', 'mobile_no', 'toll_free_no', 'fax'], 'string', 'max' => 512],
            [['slug', 'address', 'email', 'logo_base_url', 'logo_path'], 'string', 'max' => 1024],
            [['landmark'], 'string', 'max' => 500],
            [['contact_no'], 'string', 'max' => 150],
            [['latitude', 'longitude'], 'string', 'max' => 30],
            [['category_id'], 'exist', 'skipOnError' => true, 'targetClass' => Category::className(), 'targetAttribute' => ['category_id' => 'id']],
            [['district_id'], 'exist', 'skipOnError' => true, 'targetClass' => District::className(), 'targetAttribute' => ['district_id' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('common', 'ID'),
            'category_id' => Yii::t('common', 'Category'),
            'district_id' => Yii::t('common', 'District'),
            'domain_name' => Yii::t('common', 'Domain Name'),
            'name' => Yii::t('common', 'Name'),
            'slug' => Yii::t('common', 'Slug'),
            'address' => Yii::t('common', 'Address'),
            'landmark' => Yii::t('common', 'Landmark'),
            'mobile_no' => Yii::t('common', 'Mobile No'),
            'toll_free_no' => Yii::t('common', 'Toll Free No'),
            'contact_no' => Yii::t('common', 'Contact No'),
            'fax' => Yii::t('common', 'Fax'),
            'email' => Yii::t('common', 'Email'),
            'description' => Yii::t('common', 'Description'),
            'logo_base_url' => Yii::t('common', 'Logo Base Url'),
            'logo_path' => Yii::t('common', 'Logo Path'),
            'latitude' => Yii::t('common', 'Latitude'),
            'longitude' => Yii::t('common', 'Longitude'),
            'status' => Yii::t('common', 'Status'),
            'created_at' => Yii::t('common', 'Created At'),
            'updated_at' => Yii::t('common', 'Updated At'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCategory()
    {
        return $this->hasOne(Category::className(), ['id' => 'category_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getDistrict()
    {
        return $this->hasOne(District::className(), ['id' => 'district_id']);
    }

    /**
     * @inheritdoc
     * @return \common\models\query\BusinessQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \common\models\query\BusinessQuery(get_called_class());
    }

    public static function statuses()
    {
        return [
            self::STATUS_ACTIVE => Yii::t('common', 'Active'),
            self::STATUS_IN_ACTIVE => Yii::t('common', 'In Active'),
        ];
    }

}
