<?php

namespace common\models;

use Yii;
use yii\behaviors\TimestampBehavior;
use MongoDB\BSON\UTCDatetime;

/**
 * This is the model class for table "{{%website}}".
 *
 * @property integer $id
 * @property integer $business_id
 * @property integer $theme_id
 * @property string $domain_name
 * @property integer $status
 * @property integer $expiry_date
 * @property integer $created_at
 * @property integer $updated_at
 *
 * @property Theme $theme
 */
class Website extends \yii\db\ActiveRecord
{
    const STATUS_ACTIVE = 1;
    const STATUS_IN_ACTIVE = 0;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%website}}';
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at'
            ]
        ];
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['business_id', 'theme_id', 'status', 'expiry_date','created_at', 'updated_at'], 'integer'],
            [['domain_name'], 'required'],
            [['domain_name'], 'string', 'max' => 255],
            [
                ['theme_id'],
                'exist',
                'skipOnError' => true,
                'targetClass' => Theme::className(),
                'targetAttribute' => ['theme_id' => 'id']
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => Yii::t('common', 'ID'),
            'business_id' => Yii::t('common', 'Business'),
            'theme_id' => Yii::t('common', 'Theme'),
            'domain_name' => Yii::t('common', 'Domain Name'),
            'status' => Yii::t('common', 'Status'),
            'expiry_date' => Yii::t('common', 'Expiry Date'),
            'created_at' => Yii::t('common', 'Created At'),
            'updated_at' => Yii::t('common', 'Updated At'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getTheme()
    {
        return $this->hasOne(Theme::className(), ['id' => 'theme_id']);
    }

    /**
     * @inheritdoc
     * @return \common\models\query\WebsiteQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \common\models\query\WebsiteQuery(get_called_class());
    }

    /**
     * @return array
     * status drop down list used in view
     */
    public static function statuses()
    {
        return [
            self::STATUS_ACTIVE => Yii::t('common', 'Active'),
            self::STATUS_IN_ACTIVE => Yii::t('common', 'In Active'),
        ];
    }

    public function beforeSave($insert)
    {
        if (parent::beforeSave($insert)) {
            $expiry_date = date('Y-m-d', strtotime('+1 years'));
            $this->expiry_date = strtotime($expiry_date);
            return true;
        } else {
            return false;
        }
    }
}
